@@ -15,6 +15,7 @@ def test_sample_report(testdir, pytestconfig):
         "   mark_with_args",
     ])
     testdir.copy_example("samples")
+    testdir.copy_example("../screenshot.png")
 
     report = "{}/report/report.html".format(pytestconfig.rootdir)
     result = testdir.runpytest(
@@ -22,6 +23,11 @@ def test_sample_report(testdir, pytestconfig):
         "--template=html1/index.html",
         "--report=" + report
     )
+    testdir.runpytest(
+        "--template=html1/index.html",
+        "--split-report",
+        "--report={}/report/split_report.html".format(pytestconfig.rootdir)
+    )
     assert result.ret == 1
     with open(report) as fp:
         soup = BeautifulSoup(fp, "html.parser")
